use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::Version 0.002004
BEGIN { eval "use Test::Version; 1;" or die $@; }

my @imports = ('version_all_ok');

my $params = {
    is_strict   => 0,
    has_version => 1,
};

push @imports, $params
  if version->parse($Test::Version::VERSION) >= version->parse('1.002');

Test::Version->import(@imports);

version_all_ok;
done_testing;
